@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vteglyph.c,v 1.12 2003/05/19 20:55:11 nalin Exp $"
+#ident "$Id: vteglyph.c,v 1.14 2004/04/20 05:16:56 nalin Exp $"
 
 #include "../config.h"
 
@@ -134,9 +134,11 @@ _vte_glyph_cache_free(struct _vte_glyph_cache *cache)
 }
 
 void
-_vte_glyph_cache_set_font_description(FcConfig *config,
+_vte_glyph_cache_set_font_description(GtkWidget *widget,
+				      FcConfig *config,
 				      struct _vte_glyph_cache *cache,
 				      const PangoFontDescription *fontdesc,
+				      VteTerminalAntiAlias antialias,
 				      _vte_fc_defaults_cb defaults_cb,
 				      gpointer defaults_data)
 {
@@ -154,7 +156,9 @@ _vte_glyph_cache_set_font_description(FcConfig *config,
 
 	/* Convert the font description to a sorted set of patterns. */
 	patterns = g_array_new(TRUE, TRUE, sizeof(FcPattern*));
-	if (!_vte_fc_patterns_from_pango_font_desc(fontdesc, patterns,
+	if (!_vte_fc_patterns_from_pango_font_desc(widget, fontdesc,
+						   antialias,
+						   patterns,
 						   defaults_cb,
 						   defaults_data)) {
 		g_array_free(patterns, TRUE);
